;; Generated package description from fontaine.el  -*- no-byte-compile: t -*-
(define-package "fontaine" "0.4.1.0.20230210.124359" "Set font configurations using presets" '((emacs "27.1")) :commit "d4c958feb47d7b7cc2f0d91252bb7827af546dae" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Fontaine Development" . "~protesilaos/fontaine@lists.sr.ht") :url "https://git.sr.ht/~protesilaos/fontaine")
